dm: treewide: Rename 'platdata' variables to just 'plat'

We use 'priv' for private data but often use 'platdata' for platform data.
We can't really use 'pdata' since that is ambiguous (it could mean private
or platform data).

Rename some of the latter variables to end with 'plat' for consistency.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/include/dm/device-internal.h b/include/dm/device-internal.h
index 578a483..2e9c1d5 100644
--- a/include/dm/device-internal.h
+++ b/include/dm/device-internal.h
@@ -19,8 +19,8 @@
  * device_bind() - Create a device and bind it to a driver
  *
  * Called to set up a new device attached to a driver. The device will either
  * have platdata, or a device tree node which can be used to create the
  * platdata.
  *
  * Once bound a device exists but is not yet active until device_probe() is
  * called.
@@ -28,7 +28,7 @@
  * @parent: Pointer to device's parent, under which this driver will exist
  * @drv: Device's driver
  * @name: Name of device (e.g. device tree node name)
  * @platdata: Pointer to data for this device - the structure is device-
  * specific but may include the device's I/O address, etc.. This is NULL for
  * devices which use device tree.
  * @ofnode: Devicetree node for this device. This is ofnode_null() for
@@ -37,7 +37,7 @@
  * @return 0 if OK, -ve on error
  */
 int device_bind(struct udevice *parent, const struct driver *drv,
-		const char *name, void *platdata, ofnode node,
+		const char *name, void *plat, ofnode node,
 		struct udevice **devp);
 
 /**
@@ -72,7 +72,7 @@
  * @parent: Pointer to device's parent
  * @pre_reloc_only: If true, bind the driver only if its DM_FLAG_PRE_RELOC flag
  * is set. If false bind the driver always.
  * @info: Name and platdata for this device
  * @devp: if non-NULL, returns a pointer to the bound device
  * @return 0 if OK, -ve on error
  */
@@ -19,8 +19,8 @@
  *
  * Called to set up a new device attached to a driver. The device will either
- * have platdata, or a device tree node which can be used to create the
- * platdata.
+ * have plat, or a device tree node which can be used to create the
+ * plat.
  *
  * Once bound a device exists but is not yet active until device_probe() is
@@ -28,7 +28,7 @@
  * @drv: Device's driver
  * @name: Name of device (e.g. device tree node name)
- * @platdata: Pointer to data for this device - the structure is device-
+ * @plat: Pointer to data for this device - the structure is device-
  * specific but may include the device's I/O address, etc.. This is NULL for
  * devices which use device tree.
@@ -72,7 +72,7 @@
  * @pre_reloc_only: If true, bind the driver only if its DM_FLAG_PRE_RELOC flag
  * is set. If false bind the driver always.
- * @info: Name and platdata for this device
+ * @info: Name and plat for this device
  * @devp: if non-NULL, returns a pointer to the bound device
  * @return 0 if OK, -ve on error